@@ -28,26 +28,6 @@ from time import sleep
 class Item:
     node = None
     xpath = ""
-    __text = ""
-    __tempId = ""
-    __x = 0.0
-    __y = 0.0
-    __z = 0
-    __center_x_to_item = 0.0
-    __center_y_to_item = 0.0
-    __center_x_to_global = 0.0
-    __center_y_to_global = 0.0
-    __height = 0.0
-    __width = 0.0
-    __className = ""
-    __objectName = ""
-    __opacity = 0.0
-    __focus = None
-    __enabled = None
-    __visible = None
-    __scale = 0.0
-    __rotation = 0
-    __clip = None
     device = None
     sopid = ""
     __display_width = 0
@@ -61,8 +41,6 @@ class Item:
         self.__display_height = self.device.display_height()
         self.xpath = xpath
         self.__refresh_node()
-        if self.node is not None:
-            self.__refresh_attribute()
 
     def __refresh_node(self):
         self.node = None
@@ -71,6 +49,9 @@ class Item:
         nodes = selector.xpath(self.xpath)
         if len(nodes) > 0 and selector.get("sopId") == self.sopid:
             self.node = nodes[0]
+            self.__refresh_attribute()
+        else:
+            self.__init_attribute()
 
     def __refresh_attribute(self):
         self.__x = float(self.node.get("x"))
@@ -83,7 +64,7 @@ class Item:
         self.__height = float(self.node.get("height"))
         self.__width = float(self.node.get("width"))
         self.__tempId = self.node.get("tempID")
-        self.__text__ = self.node.get("text")
+        self.__text = self.node.get("text")
         self.__objectName = self.node.get("objectName")
         self.__className = self.node.tag
         self.__opacity = float(self.node.get("opacity"))
@@ -94,124 +75,126 @@ class Item:
         self.__rotation = int(self.node.get("rotation"))
         self.__clip = bool(int(self.node.get("clip")))
 
+    def __init_attribute(self):
+        self.__text = ""
+        self.__tempId = ""
+        self.__x = 0.0
+        self.__y = 0.0
+        self.__z = 0
+        self.__center_x_to_item = 0.0
+        self.__center_y_to_item = 0.0
+        self.__center_x_to_global = 0.0
+        self.__center_y_to_global = 0.0
+        self.__height = 0.0
+        self.__width = 0.0
+        self.__className = ""
+        self.__objectName = ""
+        self.__opacity = 0.0
+        self.__focus = None
+        self.__enabled = None
+        self.__visible = None
+        self.__scale = 0.0
+        self.__rotation = 0
+        self.__clip = None
+
     def x(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__x
 
     def y(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__y
 
     def center_x_to_item(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__center_x_to_item
 
     def center_y_to_item(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__center_y_to_item
 
     def center_x_to_global(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__center_x_to_global
 
     def center_y_to_global(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__center_y_to_global
 
     def z(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__z
 
     def scale(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__scale
 
     def rotation(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__rotation
 
     def clip(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__clip
 
     def height(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__height
 
     def width(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__width
 
     def temp_id(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__tempId
 
     def text(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
-        return self.__text__
+        return self.__text
 
     def object_name(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__objectName
 
     def class_name(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__className
 
     def opacity(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__opacity
 
     def enabled(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__enabled
 
     def visible(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__visible
 
     def focus(self, refresh=False):
         if refresh:
             self.__refresh_node()
-            self.__refresh_attribute()
         return self.__focus
 
     def exist(self, timeout=None):
@@ -570,7 +553,8 @@ class Item:
         return image
 
     def click(self):
-        self.device.click(self.__center_x_to_global, self.__center_y_to_global)
+        if self.node is not None:
+            self.device.click(self.__center_x_to_global, self.__center_y_to_global)
 
     def click_exist(self, timeout=None):
         if self.exist(timeout):
